Index: branches/5.2.x/core/kernel/utility/debugger/debugger.js
===================================================================
diff -u -r15530 -r15730
--- branches/5.2.x/core/kernel/utility/debugger/debugger.js (.../debugger.js) (revision 15530)
+++ branches/5.2.x/core/kernel/utility/debugger/debugger.js (.../debugger.js) (revision 15730)
@@ -507,24 +507,6 @@
return alert($ret);
}
-Debugger.prototype.editFile = function($fileName, $lineNo) {
- if (!document.all) {
- alert('Only works in IE');
- return;
- }
-
- if (!this.EditorPath) {
- alert('Editor path not defined!');
- return;
- }
-
- var $launch_object = new ActiveXObject('LaunchinIE.Launch');
- var $editor_path = this.EditorPath;
- $editor_path = $editor_path.replace('%F', $fileName);
- $editor_path = $editor_path.replace('%L',$lineNo);
- $launch_object.LaunchApplication($editor_path);
-}
-
Debugger.prototype.ToggleTraceArgs = function($arguments_layer_id) {
var $arguments_layer = document.getElementById($arguments_layer_id);
$arguments_layer.style.display = ($arguments_layer.style.display == 'none') ? 'block' : 'none';
Index: branches/5.2.x/core/kernel/utility/debugger.php
===================================================================
diff -u -r15701 -r15730
--- branches/5.2.x/core/kernel/utility/debugger.php (.../debugger.php) (revision 15701)
+++ branches/5.2.x/core/kernel/utility/debugger.php (.../debugger.php) (revision 15730)
@@ -1,6 +1,6 @@
'F12', // Defines debugger activation shortcut (any symbols or Ctrl/Alt/Shift are allowed, e.g. Ctrl+Alt+F12)
);
- // only for IE, in case if no windows php script editor defined
- if (!defined('DBG_EDITOR')) {
-// $dbg_constMap['DBG_EDITOR'] = 'c:\Program Files\UltraEdit\uedit32.exe %F/%L';
- $dbg_constMap['DBG_EDITOR'] = 'c:\Program Files\Zend\ZendStudio-5.2.0\bin\ZDE.exe %F';
- }
-
// debugger is initialized before kHTTPQuery, so do jQuery headers check here too
if (array_key_exists('HTTP_X_REQUESTED_WITH', $_SERVER) && $_SERVER['HTTP_X_REQUESTED_WITH'] == 'XMLHttpRequest') {
$this->_isAjax = true;
@@ -936,23 +930,18 @@
* Returns link for editing php file (from error) in external editor
*
* @param string $file filename with path from root folder
* @param int $lineno line number in file where error is found
* @param string $title text to show on file edit link
* @return string
* @access public
*/
- public function getFileLink($file, $lineno = 1, $title = '')
+ public function getFileLink($file, $line_number = 1, $title = '')
{
if ( !$title ) {
$title = str_replace('/', '\\', $this->getLocalFile($file));
}
- if ( $this->isGecko() ) {
- return '' . $title . '';
- }
- else {
- return '' . $title . '';
- }
+ return '' . $title . '';
}
/**
@@ -1600,7 +1589,6 @@
$Debugger.createEnvironment(, getWindowWidth(); ?>);
$Debugger.DOMViewerURL = '';
- $Debugger.EditorPath = '';
$Debugger.DebugURL = 'baseURL.'/debugger_responce.php?sid='.$this->rowSeparator.'&path='.urlencode($dbg_path); ?>';
$Debugger.EventURL = 'Factory) &&*/ $application->InitDone ? $application->HREF('dummy', '', Array ('pass' => 'm', '__NO_REWRITE__' => 1)) : ''; ?>';
$Debugger.BasePath = 'basePath; ?>';
@@ -936,23 +930,18 @@
*
* @param string $file filename with path from root folder
- * @param int $lineno line number in file where error is found
+ * @param int $line_number line number in file where error is found
* @param string $title text to show on file edit link
* @return string